<?php
/**
 * Exit if accessed directly
 */
defined( 'ABSPATH' ) || exit( 'دسترسی غیر مجاز!' );

class WIP_Shop_Order_MTB {

	public static function init() {
		add_action( 'add_meta_boxes', array( self::class, 'add' ) );
		add_action( 'save_post', array( self::class, 'save' ) );
	}

	public static function add() {
		add_meta_box(
			'woocommerce-invoice-pro',
			'صدور فاکتور',
			array( self::class, 'display' ),
			'shop_order',
			'side',
			'low'
		);
	}

	public static function display( $post ) {
		echo '<a style="width:162px; text-align:center" class="button" target="_blank" href="' . esc_url( add_query_arg( array(
				'wip-print-invoice' => 1,
				'wip-print-type'    => 'invoice',
				'wip-order-id'      => $post->ID,
				'_wip_nonce'        => wp_create_nonce( '_wip_nonce' ),
			), admin_url() ) ) . '">برگه فاکتور</a>';
		echo '<br><br>';
		echo '<a style="width:162px; text-align:center" class="button" target=_blank"" href="' . esc_url( add_query_arg( array(
				'wip-print-invoice' => 1,
				'wip-print-type'    => 'packing-slip',
				'wip-order-id'      => $post->ID,
				'_wip_nonce'        => wp_create_nonce( '_wip_nonce' ),
			), admin_url() ) ) . '">برگه انبارداری</a>';
		echo '<br><br>';
		echo '<a style="width:162px; text-align:center" class="button" target=_blank"" href="' . esc_url( add_query_arg( array(
				'wip-print-invoice' => 1,
				'wip-print-type'    => 'post-label',
				'wip-order-id'      => $post->ID,
				'_wip_nonce'        => wp_create_nonce( '_wip_nonce' ),
			), admin_url() ) ) . '">برچسب پستی</a>';
		echo '<br><br>';
		echo '<a style="width:162px; text-align:center" class="button" target=_blank"" href="' . esc_url( add_query_arg( array(
				'wip-print-invoice' => 1,
				'wip-print-type'    => 'sender-post-label',
				'wip-order-id'      => $post->ID,
				'_wip_nonce'        => wp_create_nonce( '_wip_nonce' ),
			), admin_url() ) ) . '">برچسب پستی فرستنده</a>';
		echo '<br><br>';
		echo '<a style="width:162px; text-align:center" class="button" target=_blank"" href="' . esc_url( add_query_arg( array(
				'wip-print-invoice' => 1,
				'wip-print-type'    => 'recipient-post-label',
				'wip-order-id'      => $post->ID,
				'_wip_nonce'        => wp_create_nonce( '_wip_nonce' ),
			), admin_url() ) ) . '">برچسب پستی گیرنده</a>';
		echo '<br><br>';
		echo '<a style="width:162px; text-align:center" href="#" class="wip-send-invoice button" data-order-id="' . $post->ID . '">ارسال برگه فاکتور</a>';
		echo '<img class="wip-ajax-loader" src="' . esc_url( admin_url() ) . 'images/spinner.gif" alt="Please wait…" style="margin: 5px; display: none;">';

		$inactive          = get_post_meta( $post->ID, '_wip_inactive_for_seller', true );
		$invoice_note      = get_post_meta( $post->ID, '_wip_invoice_note', true );
		$packing_slip_note = get_post_meta( $post->ID, '_wip_packing_slip_note', true );
		?>
        <br><br>
        <label for="inactive_for_seller">
            <input name="inactive-for-seller" type="checkbox" id="inactive-for-seller" value="1" <?php checked( $inactive, 1 ); ?>>
            <span>عدم دسترسی فروشنده</span>
        </label>
        <p class="description" style="margin-top: 7px;">
            <small>با انتخاب این گزینه فروشنده افزونه دکان به فاکتورهای این سفارش دسترسی نخواهد داشت.</small>
        </p>
        <br><br>
        <label for="invoice-note">یادداشت برگه فاکتور</label>
        <textarea id="invoice-note" name="invoice-note" rows="5" style="width: 100%;"><?php echo esc_textarea( $invoice_note ); ?></textarea>
        <br><br>
        <label for="packing-slip-note">یادداشت برگه انبارداری</label>
        <textarea id="packing-slip-note" name="packing-slip-note" rows="5" style="width: 100%;"><?php echo esc_textarea( $packing_slip_note ); ?></textarea>
		<?php
		wp_nonce_field( 'security', 'wip_mtb_nonce' );
	}

	public static function save( $post_id ) {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! isset( $_POST['wip_mtb_nonce'] ) || ! wp_verify_nonce( $_POST['wip_mtb_nonce'], 'security' ) ) {
			return;
		}

		if ( ! current_user_can( 'edit_post' ) ) {
			return;
		}

		if ( ! isset( $_POST['inactive-for-seller'] ) ) {
			delete_post_meta( $post_id, '_wip_inactive_for_seller' );
		} else {
			update_post_meta( $post_id, '_wip_inactive_for_seller', 1 );
		}

		if ( ! isset( $_POST['invoice-note'] ) || empty( $_POST['invoice-note'] ) ) {
			delete_post_meta( $post_id, '_wip_invoice_note' );
		} else {
			update_post_meta( $post_id, '_wip_invoice_note', sanitize_textarea_field( $_POST['invoice-note'] ) );
		}

		if ( ! isset( $_POST['packing-slip-note'] ) || empty( $_POST['packing-slip-note'] ) ) {
			delete_post_meta( $post_id, '_wip_packing_slip_note' );
		} else {
			update_post_meta( $post_id, '_wip_packing_slip_note', sanitize_textarea_field( $_POST['packing-slip-note'] ) );
		}
	}
}