<?php
/**
 * Exit if accessed directly
 */
defined( 'ABSPATH' ) || exit( 'دسترسی غیر مجاز!' );

add_filter( 'woocommerce_get_settings_pages', 'wip_add_settings', 15 );
function wip_add_settings() {

	/**
	 * Settings class
	 */
	class WIP_Settings_Tab_SRezaSalehi extends WC_Settings_Page {

		/**
		 * Setup settings class
		 */
		public function __construct() {

			$this->id    = 'woo_invoice_pro';
			$this->label = 'فاکتور';

			add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_page' ), 20 );
			add_action( 'woocommerce_settings_' . $this->id, array( $this, 'output' ) );
			add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );
			add_action( 'woocommerce_sections_' . $this->id, array( $this, 'output_sections' ) );
		}

		/**
		 * Get sections
		 *
		 * @return array
		 */
		public function get_sections() {

			$sections = array(
				''         => 'فروشگاه',
				'customer' => 'مشتری',
				'template' => 'قالب',
				'others'   => 'متفرقه',
			);

			return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
		}

		/**
		 * Get settings array
		 *
		 * @param string $current_section Optional. Defaults to empty string.
		 *
		 * @return array Array of settings
		 */
		public function get_settings( $current_section = '' ) {

			if ( $current_section == 'customer' ) {
				$settings = apply_filters( 'woo_invoice_pro_customer_settings', array(
					'customer_info_title'    => array(
						'name' => 'اطلاعات مشتری',
						'type' => 'title',
						'id'   => 'wc_wip_settings_customer_info_title'
					),
					'customer_address'       => array(
						'name' => 'آدرس خریدار',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_customer_address',
						'desc' => 'نمایش',
					),
					'customer_phone'         => array(
						'name' => 'تلفن خریدار',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_customer_phone',
						'desc' => 'نمایش',
					),
					'customer_email'         => array(
						'name' => 'ایمیل خریدار',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_customer_email',
						'desc' => 'نمایش',
					),
					'order_date'             => array(
						'name' => 'تاریخ سفارش',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_order_date',
						'desc' => 'نمایش',
					),
					'shipping_method'        => array(
						'name' => 'روش پرداخت',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_shipping_method',
						'desc' => 'نمایش',
					),
					'transaction_id'         => array(
						'name' => 'شماره تراکنش',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_transaction_id',
						'desc' => 'نمایش',
					),
					'order_table'            => array(
						'name' => 'جدول سفارش',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_order_table',
						'desc' => 'نمایش',
					),
					'total_table'            => array(
						'name' => 'جدول کل',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_total_table',
						'desc' => 'نمایش',
					),
					'customer_note'          => array(
						'name'    => 'یادداشت مشتری',
						'type'    => 'select',
						'id'      => 'wc_wip_settings_customer_note',
						'class'   => 'wc-enhanced-select',
						'options' => array(
							'both'         => 'هردو',
							'none'         => 'هیچکدام',
							'invoice'      => 'فاکتور',
							'packing_slip' => 'برگه انبارداری',
						),
					),
					'national_id'            => array(
						'name'     => 'شماره ملی/کد اقتصادی',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_national_id',
						'desc'     => 'فعال',
						'desc_tip' => 'با فعال بودن این گزینه مستقل از قالب فعلی شما فیلد شماره ملی به فرم تسویه حساب اضافه خواهد شد و در فاکتور نیز قابل نمایش می‌باشد.',
					),
					'optimize_customer_addr' => array(
						'name'     => 'بهینه‌سازی آدرس',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_optimize_customer_addr',
						'desc'     => 'فعال',
						'desc_tip' => 'جهت بهینه سازی نمایش آدرس مشتری این گزینه را فعال نمایید.',
					),
					'customer_info_end'      => array(
						'type' => 'sectionend',
						'id'   => 'wc_wip_settings_customer_info_end'
					),
				) );
			} elseif ( $current_section == 'template' ) {
				$settings = apply_filters( 'woo_invoice_pro_template_settings', array(
					'template_title'               => array(
						'name' => 'پیکربندی قالب',
						'type' => 'title',
						'id'   => 'wc_wip_settings_footer_title'
					),
					'tpl_color'                    => array(
						'name'    => 'رنگ قالب',
						'type'    => 'select',
						'id'      => 'wc_wip_settings_tpl_color',
						'class'   => 'wc-enhanced-select',
						'options' => array(
							'484848' => 'خاکستری',
							'27ae60' => 'سبز 1',
							'16a085' => 'سبز 2',
							'00cec9' => 'سبزآبی',
							'2980b9' => 'آبی',
							'e74c3c' => 'قرمز',
							'ffa502' => 'نارنجی',
							'fff200' => 'زرد',
						),
					),
					'template'                     => array(
						'name'    => 'قالب فاکتور',
						'type'    => 'select',
						'class'   => 'wc-enhanced-select',
						'id'      => 'wc_wip_settings_template',
						'options' => array(
							'template1' => 'قالب شماره 1',
							'template2' => 'قالب شماره 2',
							'template3' => 'قالب شماره 3',
							'template4' => 'قالب شماره 4',
						),
					),
					'post_label_template'          => array(
						'name'    => 'قالب برچسب پستی',
						'type'    => 'select',
						'class'   => 'wc-enhanced-select',
						'id'      => 'wc_wip_settings_post_label_template',
						'options' => array(
							'template1' => 'قالب شماره 1',
							'template2' => 'قالب شماره 2',
						),
					),
					'font_family'                  => array(
						'name'     => 'نوع فونت',
						'type'     => 'select',
						'class'    => 'wc-enhanced-select',
						'id'       => 'wc_wip_settings_font_family',
						'options'  => array(
							''         => 'لطفا انتخاب کنید.',
							'vazir'    => 'وزیر',
							'yekan'    => 'یکان',
							'bnazanin' => 'نازنین',
							'bkoodak'  => 'کودک',
							'IRANSans' => 'ایران سنس',
						),
						'desc_tip' => 'جهت استفاده از فونت ایران سنس، فایل فونت را با فرمت های eot,ttf,woff,woff2 و نام IRANSans در پوشه assets/fonts/iransans قرار دهید.',
					),
					'font_size'                    => array(
						'name'              => 'اندازه فونت',
						'type'              => 'number',
						'id'                => 'wc_wip_settings_font_size',
						'custom_attributes' => array(
							'dir'  => 'ltr',
							'step' => '1',
							'min'  => '12',
							'max'  => '26',
						)
					),
					'invoice_prefix'               => array(
						'name'              => 'پیشوند شماره فاکتور',
						'type'              => 'text',
						'desc_tip'          => 'برای شماره فاکتور یک پیشوند انتخاب کنید.',
						'id'                => 'wc_wip_settings_invoice_prefix',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'invoice_suffix'               => array(
						'name'              => 'پسوند شماره فاکتور',
						'type'              => 'text',
						'desc_tip'          => 'برای شماره فاکتور یک پسوند انتخاب کنید.',
						'id'                => 'wc_wip_settings_invoice_suffix',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'invoice_start'                => array(
						'name'              => 'شماره شروع فاکتور',
						'type'              => 'number',
						'desc_tip'          => 'این عدد به تمامی شماره فاکتور ها اضافه خواهد شد.',
						'id'                => 'wc_wip_settings_invoice_start',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'barcode'                      => array(
						'name' => 'بارکد',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_barcode',
						'desc' => 'نمایش',
					),
					'barcode_sender_post_label'    => array(
						'name' => 'نمایش بارکد در برچسب فرستنده',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_barcode_sender_post_label',
						'desc' => 'نمایش',
					),
					'barcode_recipient_post_label' => array(
						'name' => 'نمایش بارکد در برچسب گیرنده',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_barcode_recipient_post_label',
						'desc' => 'نمایش',
					),
					'condensed'                    => array(
						'name'     => 'حالت فشرده',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_condensed',
						'desc'     => 'فعال',
						'desc_tip' => 'درصورتی که از برگه A5 استفاده میکنید میتوانید این گزینه را فعال کنید.',
					),
					'margin'                       => array(
						'name'              => 'فاصله از لبه',
						'type'              => 'number',
						'desc_tip'          => 'فاصله فاکتور از لبه برگه را به پیکسل وارد کنید.',
						'id'                => 'wc_wip_settings_margin',
						'custom_attributes' => array(
							'dir'  => 'ltr',
							'step' => '1',
							'min'  => '0',
						)
					),
					'price_type'                   => array(
						'name'    => 'قیمت محصول',
						'type'    => 'select',
						'class'   => 'wc-enhanced-select',
						'id'      => 'wc_wip_settings_price_type',
						'options' => array(
							'sale'         => 'قیمت فروش فوق‌العاده',
							'regular_sale' => 'قیمت اصلی + قیمت فروش فوق‌العاده',
						),
					),
					'price'                        => array(
						'name'    => 'نمایش قیمت محصول',
						'type'    => 'select',
						'class'   => 'wc-enhanced-select',
						'id'      => 'wc_wip_settings_price',
						'options' => array(
							'both'         => 'هردو',
							'none'         => 'هیچکدام',
							'invoice'      => 'فاکتور',
							'packing_slip' => 'برگه انبارداری',
						),
					),
					'weight'                       => array(
						'name'     => 'وزن محصول',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_weight',
						'desc'     => 'نمایش',
						'desc_tip' => 'وزن محصول فقط در برگه انبارداری نمایش داده میشود.',
					),
					'dimensions'                   => array(
						'name'     => 'ابعاد محصول',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_dimensions',
						'desc'     => 'نمایش',
						'desc_tip' => 'ابعاد محصول فقط در برگه انبارداری نمایش داده میشود.',
					),
					'cabinet_code'                 => array(
						'name'     => 'کد قفسه انبار',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_cabinet_code',
						'desc'     => 'نمایش',
						'desc_tip' => 'با اختصاص کد قفسه انبار برای محصولات در تب انبار، این کد در برگه انبارداری نمایش داده میشود.',
					),
					'product_id'                   => array(
						'name'     => 'شناسه',
						'type'     => 'radio',
						'id'       => 'wc_wip_settings_product_id',
						'options'  => array(
							'p_id'  => 'شناسه محصول',
							'p_sku' => 'شناسه اختصاصی محصول',
						),
						'desc_tip' => 'منظور از شناسه اختصاصی محصول، شناسه ای است که در تب انبار وارد میکنید. اگر این شناسه موجود نباشد شناسه محصول جایگزین میشود.',
					),
					'show_product_id'              => array(
						'name'    => 'نمایش شناسه محصول',
						'type'    => 'select',
						'class'   => 'wc-enhanced-select',
						'id'      => 'wc_wip_settings_show_product_id',
						'options' => array(
							'both'         => 'هردو',
							'none'         => 'هیچکدام',
							'invoice'      => 'فاکتور',
							'packing_slip' => 'برگه انبارداری',
						),
					),
					'total_quantity'               => array(
						'name' => 'تعداد کل اقلام',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_total_quantity',
						'desc' => 'نمایش',
					),
					'discount_amount'              => array(
						'name'     => 'تخفیف کل محصولات',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_discount_amount',
						'desc'     => 'نمایش',
						'desc_tip' => 'تخفیف کل محصولات با عنوان "سود شما از این خرید" نمایش داده میشود.',
					),
					'tax'                          => array(
						'name'     => 'مالیات',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_tax',
						'desc'     => 'نمایش',
						'desc_tip' => 'با فعال بودن این گزینه در صورتی که نرخ استاندارد مالیات داشته باشید، در جدول کل نمایش داده میشود.',
					),
					'signature'                    => array(
						'name'              => 'مهر و امضا',
						'type'              => 'text',
						'class'             => 'select-uploader',
						'desc'              => '',
						'desc_tip'          => 'تصویر مهر و امضا فروشگاه خود را جهت نمایش در فاکتور انتخاب کنید.',
						'id'                => 'wc_wip_settings_signature',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'refunded_items'               => array(
						'name'     => 'محصولات مسترد شده',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_refunded_items',
						'desc'     => 'فعال',
						'desc_tip' => 'چنانچه محصولی را از سفارش مسترد شده باشید، تعداد و مبلغ برای هر محصول بصورت مجزا در فاکتور نمایش داده خواهد شد.',
					),
					'product_img'                  => array(
						'name'    => 'تصویر محصول',
						'type'    => 'select',
						'id'      => 'wc_wip_settings_product_img',
						'class'   => 'wc-enhanced-select',
						'options' => array(
							'none'         => 'هیچکدام',
							'both'         => 'هردو',
							'invoice'      => 'فاکتور',
							'packing_slip' => 'برگه انبارداری',
						),
					),
					'watermark'                    => array(
						'name'              => 'واترمارک',
						'type'              => 'text',
						'class'             => 'select-uploader',
						'desc'              => '',
						'desc_tip'          => 'یک تصویر برای واترمارک انتخاب نمایید.',
						'id'                => 'wc_wip_settings_watermark',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'watermark_opacity'            => array(
						'name'              => 'شفافیت واترمارک',
						'type'              => 'number',
						'desc_tip'          => 'مقدار شفافیت تصویر واترمارک را عددی بین 0 تا 1 وارد نمایید.',
						'id'                => 'wc_wip_settings_watermark_opacity',
						'custom_attributes' => array(
							'dir'  => 'ltr',
							'step' => '0.1',
							'min'  => '0',
							'max'  => '1',
						)
					),
					'product_name_optimize'        => array(
						'name'     => 'بهینه‌سازی نام محصول',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_product_name_optimize',
						'desc'     => 'فعال',
						'desc_tip' => 'چنانچه نام محصولات متغییر به درستی نمایش داده نمیشود، این گزینه را فعال کنید.'
					),
					'purchase_note'                => array(
						'name'    => 'نمایش یادداشت خرید',
						'type'    => 'select',
						'class'   => 'wc-enhanced-select',
						'id'      => 'wc_wip_settings_purchase_note',
						'options' => array(
							'both'         => 'هردو',
							'none'         => 'هیچکدام',
							'invoice'      => 'فاکتور',
							'packing_slip' => 'برگه انبارداری',
						),
					),
					'date_format'                  => array(
						'name'              => 'فرمت تاریخ',
						'type'              => 'text',
						'placeholder'       => 'Y/m/d H:i',
						'desc'              => '<br>از <a href="https://codex.wordpress.org/Formatting_Date_and_Time" target="_blank">اینجا</a> دریافت کنید.',
						'id'                => 'wc_wip_settings_date_format',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'persian_amount'               => array(
						'name' => 'مجموع فارسی',
						'type' => 'checkbox',
						'id'   => 'wc_wip_settings_persian_amount',
						'desc' => 'نمایش',
					),
					'template_end'                 => array(
						'type' => 'sectionend',
						'id'   => 'wc_wip_settings_footer_end'
					),
				) );
			} elseif ( $current_section == 'others' ) {
				$settings = apply_filters( 'woo_invoice_pro_others_settings', array(
					'others_title'            => array(
						'name' => 'متفرقه',
						'type' => 'title',
						'id'   => 'wc_wip_settings_others_title'
					),
					'send_email'              => array(
						'name'     => 'ارسال فاکتور',
						'type'     => 'radio',
						'id'       => 'wc_wip_settings_send_email',
						'options'  => array(
							'manual'           => 'ارسال دستی',
							'order_completed'  => 'ارسال خودکار (پس از تکمیل سفارش)',
							'payment_complete' => 'ارسال خودکار (پس از تکمیل پرداخت)',
						),
						'desc_tip' => 'از این گزینه جهت ارسال فاکتور HTML به ایمیل خریدار استفاده نمایید.',
					),
					'address_type'            => array(
						'name'     => 'سفارش',
						'type'     => 'select',
						'class'    => 'wc-enhanced-select',
						'id'       => 'wc_wip_settings_address_type',
						'options'  => array(
							'billing'  => 'آدرس صورتحساب',
							'shipping' => 'آدرس حمل و نقل',
						),
						'desc_tip' => 'با انتخاب آدرس حمل و نقل، اگر این آدرس موجود نباشد آدرس صورتحساب جایگزین میشود.',
					),
					'footer_description'      => array(
						'name'              => 'توضیحات پانوشت',
						'type'              => 'textarea',
						'id'                => 'wc_wip_settings_footer_description',
						'desc_tip'          => 'این متن در پایین فاکتور نمایش داده میشود.',
						'custom_attributes' => array(
							'rows' => '5',
						)
					),
					'proforma_invoice'        => array(
						'name'     => 'پیش فاکتور',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_proforma_invoice',
						'desc'     => 'فعال',
						'desc_tip' => 'با فعال بودن این گزینه دکمه چاپ فاکتور در جدول سفارشات مشتری فعال میشود.',
					),
					'proforma_invoice_access' => array(
						'name'     => 'محدودیت دسترسی به پیش فاکتور',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_proforma_invoice_access',
						'desc'     => 'فعال',
						'desc_tip' => 'با فعال بودن این گزینه فقط سفارشات با وضعیت تکمیل شده قابلیت دریافت پیش فاکتور را دارند.',
					),
					'vendor_addr'             => array(
						'name'     => 'آدرس فروشنده',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_vendor_addr',
						'desc'     => 'فعال',
						'desc_tip' => 'با فعال بودن این گزینه چنانچه از افزونه چند فروشندگی دکان استفاده میکنید، آدرس فروشنده با آدرس فروشگاه جایگزین میشود.',
					),
					'tiny_post_label'         => array(
						'name'     => 'برچسب های کوچک فرستنده و گیرنده',
						'type'     => 'checkbox',
						'id'       => 'wc_wip_settings_tiny_post_label',
						'desc'     => 'مخفی',
						'desc_tip' => 'با فعال بودن این گزینه آیکن برچسب های کوچک فرستنده و گیرنده در جدول سفارشات مخفی خواهد شد.',
					),
					'email_from'              => array(
						'name'              => 'ایمیل ارسال کننده',
						'type'              => 'email',
						'id'                => 'wc_wip_settings_email_from',
						'desc_tip'          => 'این ایمیل در Header ایمیل های ارسالی نمایش داده خواهد شد. در صورتی که این فیلد را خالی رها کنید، ایمیل مدیر جایگزین خواهد شد.',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'receivers_email'         => array(
						'name'              => 'ایمیل گیرنده‌گان',
						'type'              => 'text',
						'id'                => 'wc_wip_settings_receivers_email',
						'desc_tip'          => 'ایمیل گیرنده‌گان فاکتور را با کامای انگلیسی از هم جدا کنید.',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'others_end'              => array(
						'type' => 'sectionend',
						'id'   => 'wc_wip_settings_others_end'
					),
				) );
			} else {
				$settings = apply_filters( 'woo_invoice_pro_store_settings', array(
					'store_info_title' => array(
						'name' => 'اطلاعات فروشگاه',
						'type' => 'title',
						'id'   => 'wc_wip_settings_store_info_title'
					),
					'store_logo'       => array(
						'name'              => 'نشان فروشگاه',
						'type'              => 'text',
						'class'             => 'select-uploader',
						'desc'              => '',
						'desc_tip'          => 'نشان فروشگاه خود را جهت نمایش در فاکتور انتخاب کنید.',
						'id'                => 'wc_wip_settings_store_logo',
						'custom_attributes' => array( 'dir' => 'ltr', )
					),
					'store_title'      => array(
						'name' => 'عنوان فروشگاه',
						'type' => 'text',
						'id'   => 'wc_wip_settings_store_title'
					),
					'store_url'        => array(
						'name'              => 'وب سایت فروشگاه',
						'type'              => 'text',
						'id'                => 'wc_wip_settings_store_url',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'store_postcode'   => array(
						'name'              => 'کد پستی فروشگاه',
						'type'              => 'text',
						'id'                => 'wc_wip_settings_store_postcode',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'store_email'      => array(
						'name'              => 'ایمیل فروشگاه',
						'type'              => 'email',
						'id'                => 'wc_wip_settings_store_email',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'store_phone'      => array(
						'name'              => 'تلفن فروشگاه',
						'type'              => 'text',
						'id'                => 'wc_wip_settings_store_phone',
						'custom_attributes' => array(
							'dir' => 'ltr',
						)
					),
					'store_address'    => array(
						'name'     => 'آدرس فروشگاه',
						'type'     => 'textarea',
						'id'       => 'wc_wip_settings_store_address',
						'desc_tip' => 'آدرس  پستی کامل فروشگاه خود را بدون کد پستی وارد کنید. جهت عدم نمایش آدرس فروشگاه این فیلد را خالی رها کنید.',
					),
					'store_info_end'   => array(
						'type' => 'sectionend',
						'id'   => 'wc_wip_settings_store_info_end'
					),
				) );
			}

			return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings, $current_section );

		}

		/**
		 * Output the settings
		 */
		public function output() {

			global $current_section;

			$settings = $this->get_settings( $current_section );
			WC_Admin_Settings::output_fields( $settings );
		}

		/**
		 * Save settings
		 */
		public function save() {

			global $current_section;

			$settings = $this->get_settings( $current_section );
			WC_Admin_Settings::save_fields( $settings );
		}
	}

	return new WIP_Settings_Tab_SRezaSalehi();
}